@@ -29,9 +29,9 @@
 
 #include <ctime>
 #include <sstream>
+using namespace saml::logging;
 using namespace saml;
 using namespace std;
-using namespace log4cpp;
 
 class MemoryReplayCache : public IReplayCache
 {
