@@ -23,21 +23,28 @@
 */
 
 #include "internal.h"
+#include "version.h"
 
 #ifdef HAVE_DLFCN_H
 # include <dlfcn.h>
 #endif
 
+#if defined(HAVE_LOG4SHIB)
+# include <log4shib/PropertyConfigurator.hh>
+#elif defined(HAVE_LOG4CPP)
+# include <log4cpp/PropertyConfigurator.hh>
+#else
+# error "Supported logging library not available."
+#endif
+
 #include <curl/curl.h>
-#include <log4cpp/Category.hh>
-#include <log4cpp/PropertyConfigurator.hh>
 #include <xercesc/util/PlatformUtils.hpp>
 #include <xsec/framework/XSECProvider.hpp>
 
 #include <fstream>
 
+using namespace saml::logging;
 using namespace saml;
-using namespace log4cpp;
 using namespace std;
 
 SAML_EXCEPTION_FACTORY(MalformedException);
@@ -188,13 +195,13 @@ bool SAMLInternalConfig::init()
         m_log->debug("libcurl %s initialization complete",LIBCURL_VERSION);
 
         XMLPlatformUtils::Initialize();
-        m_log->debug("Xerces initialization complete");
+        m_log->debug("Xerces %s initialization complete",XERCES_FULLVERSIONDOT);
 
         soap_pool_init();
 
         XSECPlatformUtils::Initialise();
         m_xsec=new XSECProvider();
-        m_log->debug("XSEC initialization complete");
+        m_log->debug("XML-Security %s initialization complete",XSEC_FULLVERSIONDOT);
         
         if (schema_dir[schema_dir.length()-1]!='/')
             schema_dir+='/';
@@ -353,7 +360,7 @@ bool SAMLInternalConfig::init()
         return false;
     }
 
-    m_log->info("library initialization complete");
+    m_log->info("OpenSAML %s library initialization complete", OPENSAML_FULLVERSIONDOT);
     return true;
 }
 
@@ -396,7 +403,7 @@ void SAMLInternalConfig::term()
     XMLPlatformUtils::Terminate();
     curl_global_cleanup();
 
-    m_log->info("library shutdown complete");
+    m_log->info("OpenSAML %s library shutdown complete", OPENSAML_FULLVERSIONDOT);
     m_log=NULL;
 }
 
