@@ -227,7 +227,7 @@ SAMLException::SAMLException(HRESULT code, const string& msg, const namedparams&
 }
 
 SAMLException::SAMLException(const SAMLException& src)
-    : m_hr(src.m_hr), m_msg(src.m_msg), m_processedmsg(src.m_processedmsg), m_codes(src.m_codes), m_params(src.m_params),
+    : m_hr(src.m_hr), m_codes(src.m_codes), m_params(src.m_params), m_msg(src.m_msg), m_processedmsg(src.m_processedmsg),
         m_detail(NULL), m_scratch(NULL)
 {
     m_classname=src.m_classname;
@@ -552,7 +552,7 @@ DOMNode* SAMLException::toDOM(DOMDocument* doc, bool xmlns) const
                 m_detail->removeChild(hr);
             if (m_hr!=E_FAIL) {
                 char hexbuf[16];
-                sprintf(hexbuf,"0x%.8X",m_hr);
+                sprintf(hexbuf,"0x%.8lX",m_hr);
                 hexbuf[10]=0;
                 auto_ptr_XMLCh hexstr(hexbuf);
                 hr=doc->createElementNS(XML::OPENSAML_NS,L_QNAME(opensaml,Code));
