@@ -29,13 +29,12 @@
 #include <list>
 
 #include <curl/curl.h>
-#include <log4cpp/Category.hh>
 #include <xercesc/framework/MemBufInputSource.hpp>
 #include <xercesc/util/Base64.hpp>
 
-using namespace std;
+using namespace saml::logging;
 using namespace saml;
-using namespace log4cpp;
+using namespace std;
 
 namespace {
     class SOAPHTTPBindingProvider : virtual public SAMLSOAPHTTPBinding, virtual public SAMLSOAPBinding
@@ -129,9 +128,8 @@ int curl_debug_hook(CURL* handle, curl_infotype type, char* data, size_t len, vo
     // *ptr is actually a logging object
     if (!ptr) return 0;
     CategoryStream log=reinterpret_cast<Category*>(ptr)->debugStream();
-    for (char* ch=data; len && (isprint(*ch) || isspace(*ch)); len--)
+    for (unsigned char* ch=(unsigned char*)data; len && (isprint(*ch) || isspace(*ch)); len--)
         log << *ch++;
-    log << CategoryStream::ENDLINE;
     return 0;
 }
 
@@ -204,7 +202,8 @@ CURL* CURLPool::get(const char* location)
     curl_easy_setopt(handle,CURLOPT_NOPROGRESS,1);
     curl_easy_setopt(handle,CURLOPT_NOSIGNAL,1);
     curl_easy_setopt(handle,CURLOPT_FAILONERROR,1);
-    curl_easy_setopt(handle,CURLOPT_SSLVERSION,3);
+    curl_easy_setopt(handle,CURLOPT_SSLVERSION,CURL_SSLVERSION_SSLv3);
+    curl_easy_setopt(handle,CURLOPT_SSL_CIPHER_LIST,"ALL:!aNULL:!LOW:!EXPORT:!SSLv2");
     curl_easy_setopt(handle,CURLOPT_SSL_VERIFYHOST,2);
     curl_easy_setopt(handle,CURLOPT_HEADERFUNCTION,&curl_header_hook);
     curl_easy_setopt(handle,CURLOPT_WRITEFUNCTION,&curl_write_hook);
