@@ -28,9 +28,9 @@
 #include <xercesc/framework/Wrapper4InputSource.hpp>
 
 #include "internal.h"
+using namespace saml::logging;
 using namespace saml;
 using namespace std;
-using namespace log4cpp;
 
 XMLCh* XML::assign(const XMLCh* src, bool trim)
 {
@@ -162,19 +162,18 @@ XML::Parser::~Parser()
         conf.m_compat_pool->put(m_parser);
 }
 
-XML::ParserPool::ParserPool()
+XML::ParserPool::ParserPool() : m_security(new SecurityManager()), m_lock(XMLPlatformUtils::makeMutex())
 {
-    m_lock=XMLPlatformUtils::makeMutex();
 }
 
 XML::ParserPool::~ParserPool()
 {
-    while(!m_pool.empty())
-    {
+    while(!m_pool.empty()) {
         m_pool.top()->release();
         m_pool.pop();
     }
     XMLPlatformUtils::closeMutex(m_lock);
+    delete m_security;
 }
 
 void XML::ParserPool::registerSchema(const XMLCh* xmlns, const XMLCh* systemId, DOMEntityResolver* resolver)
@@ -237,6 +236,7 @@ DOMBuilder* XML::ParserPool::get(bool validating)
             DOMImplementation* impl=DOMImplementationRegistry::getDOMImplementation(impltype);
             DOMBuilder* parser=(static_cast<DOMImplementationLS*>(impl))->createDOMBuilder(DOMImplementationLS::MODE_SYNCHRONOUS,0);
             parser->setFeature(XMLUni::fgDOMNamespaces,true);
+            parser->setProperty(XMLUni::fgXercesSecurityManager, m_security);
 
             if (validating) {
                 parser->setFeature(XMLUni::fgXercesSchema,true);
@@ -338,19 +338,19 @@ bool XML::ParserPool::handleError(const DOMError& e)
         case DOMError::DOM_SEVERITY_WARNING:
             log.warnStream() << "warning on line " << locator->getLineNumber()
                 << ", column " << locator->getColumnNumber()
-                << ", message: " << temp.get() << CategoryStream::ENDLINE;
+                << ", message: " << temp.get() << logging::eol;
             return true;
 
         case DOMError::DOM_SEVERITY_ERROR:
             log.errorStream() << "error on line " << locator->getLineNumber()
                 << ", column " << locator->getColumnNumber()
-                << ", message: " << temp.get() << CategoryStream::ENDLINE;
+                << ", message: " << temp.get() << logging::eol;
             throw MalformedException(SAMLException::RESPONDER,string("XML::Parser detected an error during parsing: ") + (temp.get() ? temp.get() : "no message"));
 
         case DOMError::DOM_SEVERITY_FATAL_ERROR:
             log.critStream() << "fatal error on line " << locator->getLineNumber()
                 << ", column " << locator->getColumnNumber()
-                << ", message: " << temp.get() << CategoryStream::ENDLINE;
+                << ", message: " << temp.get() << logging::eol;
             throw MalformedException(SAMLException::RESPONDER,string("XML::Parser detected a fatal error during parsing: ") + (temp.get() ? temp.get() : "no message"));
     }
     throw MalformedException(SAMLException::RESPONDER,string("XML::Parser detected an unexpected problem during parsing: ") + (temp.get() ? temp.get() : "no message"));
