@@ -25,10 +25,17 @@
 #ifndef __saml_h__
 #define __saml_h__
 
+#if defined (_MSC_VER) || defined(__BORLANDC__)
+# include <saml/config_pub_win32.h>
+#else
+# include <saml/config_pub.h>
+#endif
+
 #include <xercesc/dom/DOM.hpp>
 #include <xercesc/framework/Wrapper4InputSource.hpp>
 #include <xercesc/sax/InputSource.hpp>
 #include <xercesc/util/BinInputStream.hpp>
+#include <xercesc/util/SecurityManager.hpp>
 #include <xercesc/util/XMLString.hpp>
 #include <xsec/dsig/DSIGSignature.hpp>
 #include <xsec/enc/XSECKeyInfoResolver.hpp>
@@ -58,6 +65,7 @@
 
 // STL headers
 #include <map>
+#include <memory>
 #include <set>
 #include <stack>
 #include <string>
@@ -65,12 +73,6 @@
 #include <iostream>
 #include <exception>
 
-#if defined (_MSC_VER) || defined(__BORLANDC__)
-# include <saml/config_pub_win32.h>
-#else
-# include <saml/config_pub.h>
-#endif
-
 using namespace xercesc;
 
 #include <saml/hresult.h>
@@ -495,6 +497,7 @@ namespace saml
             SchemaLocationMap m_SchemaLocMap;
             ResolverMap m_ResolverMap;
             std::stack<DOMBuilder*> m_pool;
+            SecurityManager* m_security;
             void* m_lock;
         };
 
@@ -603,8 +606,8 @@ namespace saml
         std::string getSourceID() const {return m_raw.substr(2,20);}            // bytes 3-22
         std::string getAssertionHandle() const {return m_raw.substr(22,20);}    // bytes 23-42
     
-        static const int SOURCEID_LENGTH;
-        static const int HANDLE_LENGTH;
+        static const unsigned int SOURCEID_LENGTH;
+        static const unsigned int HANDLE_LENGTH;
         
         // Hashes the input string into a 20-byte SourceID value.
         static std::string generateSourceId(const char* s);
@@ -628,7 +631,7 @@ namespace saml
         std::string getAssertionHandle() const {return m_raw.substr(2,20);} // bytes 3-22
         const char* getSourceLocation() const {return m_raw.c_str() + 22;}  // bytes 23-terminating null
     
-        static const int HANDLE_LENGTH;
+        static const unsigned int HANDLE_LENGTH;
     };
 
     // Most of the rest of the classes implement SAML constructs. The root
@@ -654,9 +657,8 @@ namespace saml
         SAMLObject();
         SAMLObject(std::istream& in);
         SAMLObject(std::istream& in, int minor);
-        SAMLObject(const SAMLObject& src) : m_classname(src.m_classname),
-            m_root(NULL), m_document(NULL), m_parent(NULL),
-            m_bDirty(true), m_bOwnStrings(true), m_log(NULL) {}
+        SAMLObject(const SAMLObject& src) : m_root(NULL), m_document(NULL), m_parent(NULL),
+            m_bDirty(true), m_bOwnStrings(true), m_log(NULL), m_classname(src.m_classname) {}
         SAMLObject& operator=(const SAMLObject&) { return *this; }
 
         virtual void setDirty();
@@ -2062,6 +2064,7 @@ namespace saml
     {
     public:
         SAMLConfig() : compatibility_mode(false), strict_dom_checking(true), clock_skew_secs(300), conn_pool_max(256) {}
+        virtual ~SAMLConfig() {}
 
         // enables runtime and clients to access global configuration object
         static SAMLConfig& getConfig();
